@@ -1,8 +1,8 @@
-if (getRversion() >= "3.1.0") {
-  utils::globalVariables(c("actualFile", "algorithm", "checksum", "checksum.x", "checksum.y",
-                           "filesize", "filesize.x", "filesize.y",
-                           "i.algorithm", "i.checksum", "i.filesize", "result"))
-}
+utils::globalVariables(c(
+  "actualFile", "algorithm", "checksum", "checksum.x", "checksum.y",
+  "filesize", "filesize.x", "filesize.y",
+  "i.algorithm", "i.checksum", "i.filesize", "result"
+))
 
 ################################################################################
 #' Calculate checksum
