@@ -1,7 +1,6 @@
 test_that("prepInputs works with NULL archive + file without extension, but originally a .zip", {
   skip_on_cran()
-  testInit()
-  skip_if_not_installed("terra")
+  testInit("terra", needInternet = TRUE)
   noisyOutput <- capture.output({
     testthat::expect_message({
       ras <- reproducible::prepInputs(url = "https://github.com/tati-micheletti/host/raw/master/data/unknownExtension",
@@ -14,7 +13,7 @@ test_that("prepInputs works with NULL archive + file without extension, but orig
 
 test_that("prepInputs WORKS if the file is not originally a .zip, but archive is provided (only extension matters)", {
   skip_on_cran()
-  testInit("terra")
+  testInit("terra", needInternet = TRUE)
   noisyOutput <- capture.output(
     testthat::expect_message({
       ras <- reproducible::prepInputs(url = "https://github.com/tati-micheletti/host/raw/master/data/unknownTAR",
@@ -27,7 +26,7 @@ test_that("prepInputs WORKS if the file is not originally a .zip, but archive is
 
 test_that("prepInputs WORKS if passing archive .zip", {
   skip_on_cran()
-  testInit("terra")
+  testInit("terra", needInternet = TRUE)
   noisyOutput <- capture.output(
     testthat::expect_message({
       ras <- reproducible::prepInputs(url = "https://github.com/tati-micheletti/host/raw/master/data/unknownExtension",
@@ -40,7 +39,7 @@ test_that("prepInputs WORKS if passing archive .zip", {
 
 test_that("prepInputs WORKS passing just targetFile that is NOT an archive", {
   skip_on_cran()
-  testInit("terra")
+  testInit("terra", needInternet = TRUE)
   noisyOutput <- capture.output({
     testthat::expect_message({
       ras <- reproducible::prepInputs(url = "https://github.com/tati-micheletti/host/raw/master/data/unknownTIF",
@@ -53,7 +52,7 @@ test_that("prepInputs WORKS passing just targetFile that is NOT an archive", {
 
 test_that("prepInputs WORKS passing archive + targetFile", {
   skip_on_cran()
-  testInit("terra")
+  testInit("terra", needInternet = TRUE)
   noisyOutput <- capture.output({
     testthat::expect_message({
       ras <- reproducible::prepInputs(url = "https://github.com/tati-micheletti/host/raw/master/data/unknownExtension",
