@@ -1,11 +1,10 @@
 test_that("testing terra", {
   #if (interactive()) {
-  testInitOut <- testInit("terra", needGoogleDriveAuth = FALSE,
+  testInit("terra", needGoogleDriveAuth = FALSE,
                           opts = list(reproducible.useMemoise = FALSE,
                                       "rgdal_show_exportToProj4_warnings"="none"))
   opts <- options(reproducible.cachePath = tmpCache)
   on.exit({
-    testOnExit(testInitOut)
     options(opts)
   }, add = TRUE)
 
@@ -118,12 +117,12 @@ test_that("testing terra", {
   expect_true(all(t6$elevation == 1))
   expect_true(NROW(t6) == 2)
 
-  ################
+  #
 
   t10 <- postProcessTo(xVect, v)
   expect_true(terra::ext(t10) < terra::ext(xVect))
 
-  ################
+  #
   ## following #253
   # https://github.com/PredictiveEcology/reproducible/issues/253#issuecomment-1263562631
   tf1 <- tempfile(fileext = ".shp")
